/*
******************************************************************************
File:     main.c
Info:     Generated by Atollic TrueSTUDIO(R) 8.0.0   2017-12-22

The MIT License (MIT)
Copyright (c) 2009-2017 Atollic AB

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

******************************************************************************
*/

#include <stdio.h>
#include "stm32l4xx.h"
#include "stm32l4xx_hal.h"
#include "system_clock.h"
#include "serial.h"

#include "wf_universal_driver.h"

extern void ext1IrqHandler(void);
void DumpEventInfo(uint8_t eventType, uint32_t eventData);

int main(void)
{
  HAL_Init();
  SystemClock_Config();
  Serial_Config();

  // Initialize the MRF24WG driver.
  WF_Init();

  while(1)
  {
    // Run the driver state machine.
    WF_Task();
  }
}

void HAL_GPIO_EXTI_Callback(uint16_t GPIO_Pin)
{
  // Notify the MRF24WG about incoming interrupt.
  ext1IrqHandler();
}

/**
 * @brief This function is called from the driver each time an event is received. In the example
 *        after the initialization is finished, the network scan is performed. The scan
 *        results are sent to the serial port.
 */
void WF_ProcessEvent(uint8_t eventType, uint32_t eventData)
{
  // Display the debug data about the event.
  DumpEventInfo(eventType, eventData);

  if(eventType == WF_EVENT_INITIALIZATION && eventData == WF_INIT_SUCCESSFUL) {
      WF_Scan();
  } else if (eventType == WF_EVENT_SCAN_RESULTS_READY) {
      for(int i=0; i<eventData; i++) {
        t_scanResult res;
        WF_ScanResultGet(i,  &res);
        res.ssid[res.ssidLen] = '\0';
        printf("%d. [%s] RSSI:%d\r\n",i , res.ssid, res.rssi);
      }
  }
}

/**
 * @brief Function required by the driver for network communication. Not used in the example.
 */
void WF_RxPacketReady(void)
{
}

/**
 * @brief Function required by the driver for network communication. Not used in the example.
 */
void WF_TxComplete(uint8_t *p_packet)
{
}
